# 📝 待处理

- [ ] **功能**| 支持多表数据合成
- [ ] **功能**| 支持更多单表数据合成模型
  - OCT-GAN 模型
  - CTAB-GAN 模型
  - Table-GAN 模型

# 🚧 进行中

- [ ] **功能**| 支持多表数据合成
- [ ] **功能**| 支持更多单表数据合成模型 - TVAE 模型

# ✅ 已完成

- [x] **增强**| 自动识别和处理固定关系
- [x] **文档**| 改进贡献者导读文档，添加4+1视图和概览图
- [x] **增强**| 支持十万级离散数据的高斯 Copula 数据合成
- [x] **功能**| 支持基于CTGAN的单表数据合成
- [x] **功能**| 支持基于LLM的无真实数据单表数据合成
- [x] **增强**| 支持十亿级数据的CTGAN
- [x] **增强**| 数值数据检查并引入正/负过滤
- [x] **增强**| 添加NonValueTransformer的反向转换及NAN_VALUE替换
- [x] **增强**| 添加ConstInspector和ConstValueTransformer以处理常量列
- [x] **增强**| 通过空列检查器和转换器进行数据处理
- [x] **增强**| 添加ChnPiiGenerator并增强模型处理中文敏感信息

# 🌟 长期计划

- [ ] **功能**| 建立隐私指标的评估系统
- [ ] **功能**| 建立合成质量指标的评估系统
